// This file specifically for FST usage
// Originally generated from config.h.in by configure.
// SPDX-FileCopyrightText: 2018-2026 Wilson Snyder
// SPDX-License-Identifier: CC0-1.0

/* Define to 1 if you have <alloca.h> and it should be used (not on Ultrix). */
#if !defined(__MINGW32__) && !defined(__FreeBSD__)
# define HAVE_ALLOCA_H 1
#endif

/* Define to 1 if fseeko (and presumably ftello) exists and is declared. */
#define HAVE_FSEEKO 1
